# InspectionSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**inspection_date** | **datetime** |  | 
**work_reference_number** | **str** |  | 
**location_description** | **str** |  | 
**street** | **str** |  | 
**town** | **str** |  | 
**area** | **str** |  | 
**inspection_reference_number** | **str** |  | [optional] 
**inspection_type** | [**InspectionTypeResponse**](InspectionTypeResponse.md) |  | 
**inspection_type_string** | **str** |  | 
**inspection_category** | **AllOfInspectionSummaryResponseInspectionCategory** |  | [optional] 
**inspection_category_string** | **str** |  | [optional] 
**inspection_outcome** | **AllOfInspectionSummaryResponseInspectionOutcome** |  | [optional] 
**inspection_outcome_string** | **str** |  | [optional] 
**inspector_name** | **str** |  | [optional] 
**highway_authority** | **str** |  | 
**promoter_organisation** | **str** |  | 
**made_safe_by_ha** | **bool** |  | [optional] 
**date_created** | **datetime** |  | 
**inspection_status** | [**InspectionStatusResponse**](InspectionStatusResponse.md) |  | 
**inspection_status_string** | **str** |  | 
**date_modified** | **datetime** |  | 
**promoter_response_status** | **AllOfInspectionSummaryResponsePromoterResponseStatus** |  | [optional] 
**promoter_response_status_string** | **str** |  | [optional] 
**ha_response_status** | **AllOfInspectionSummaryResponseHaResponseStatus** |  | [optional] 
**ha_response_status_string** | **str** |  | [optional] 
**auto_acceptance_due_date** | **datetime** |  | [optional] 
**is_auto_accepted** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

